==> jc-1.4.0.tar.gz: java/lang/Class__24MethodKey.h <==
// final class java.lang.Class$MethodKey

// class file dependencies
// @dep_class 7a404d648b6a6d1e java_lang_Class__24MethodKey
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_Class__24MethodKey_H_
#define _JC_java_lang_Class__24MethodKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_reflect_Method$object;

// Typedefs
typedef struct _jc_java_lang_Class__24MethodKey$sub_refs	_jc_java_lang_Class__24MethodKey$sub_refs;
typedef struct _jc_java_lang_Class__24MethodKey$sub_nonrefs	_jc_java_lang_Class__24MethodKey$sub_nonrefs;
typedef struct _jc_java_lang_Class__24MethodKey$refs	_jc_java_lang_Class__24MethodKey$refs;
typedef struct _jc_java_lang_Class__24MethodKey$nonrefs	_jc_java_lang_Class__24MethodKey$nonrefs;
typedef struct _jc_java_lang_Class__24MethodKey$object	_jc_java_lang_Class__24MethodKey$object;

typedef const struct _jc_java_lang_Class__24MethodKey$vmethods	_jc_java_lang_Class__24MethodKey$vmethods;
typedef const struct _jc_java_lang_Class__24MethodKey$vtable	_jc_java_lang_Class__24MethodKey$vtable;
typedef const struct _jc_java_lang_Class__24MethodKey$vtype	_jc_java_lang_Class__24MethodKey$vtype;

// Constructors
extern void _jc_java_lang_Class__24MethodKey$method$_init$29c13095b73e79e4(_jc_env *, struct _jc_java_lang_Class__24MethodKey$object *, struct _jc_java_lang_reflect_Method$object *);

// Virtual methods
extern jboolean _jc_java_lang_Class__24MethodKey$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_lang_Class__24MethodKey$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_java_lang_Class__24MethodKey$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_lang_Class__24MethodKey$object *);

// Virtual method descriptors
extern _jc_method _jc_java_lang_Class__24MethodKey$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_lang_Class__24MethodKey$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_java_lang_Class__24MethodKey$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_lang_Class__24MethodKey$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_lang_Class__24MethodKey$object *);
};

// Vtable
struct _jc_java_lang_Class__24MethodKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Class__24MethodKey$vmethods	java_lang_Class__24MethodKey;
};

// Vtype
struct _jc_java_lang_Class__24MethodKey$vtype {
	_jc_type			type;
	_jc_java_lang_Class__24MethodKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_Class__24MethodKey$sub_refs {
	struct _jc_java_lang_String$object	*name;
	_jc_object_array	*params;
	struct _jc_java_lang_Class$object	*returnType;
};

// Reference instance fields (object)
struct _jc_java_lang_Class__24MethodKey$refs {
    _jc_java_lang_Class__24MethodKey$sub_refs	java_lang_Class__24MethodKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_Class__24MethodKey$sub_nonrefs {
	jint	hash;
};

// Non-reference instance fields (object)
struct _jc_java_lang_Class__24MethodKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Class__24MethodKey$sub_nonrefs	java_lang_Class__24MethodKey;
};

// Object instance structure
struct _jc_java_lang_Class__24MethodKey$object {
	_jc_java_lang_Class__24MethodKey$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_Class__24MethodKey$vtype	*vtype;
	_jc_java_lang_Class__24MethodKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_Class__24MethodKey$vtype _jc_java_lang_Class__24MethodKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_Class__24MethodKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_Class__24MethodKey$class_object;

#endif	/* _JC_java_lang_Class__24MethodKey_H_ */

==> jc-1.4.6.tar.gz: java/lang/Class__24MethodKey.h <==
// final class java.lang.Class$MethodKey

// class file dependencies
// @dep_class 7a404d648b6a6d1e java_lang_Class__24MethodKey
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_Class__24MethodKey_H_
#define _JC_java_lang_Class__24MethodKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_reflect_Method$object;

// Typedefs
typedef struct _jc_java_lang_Class__24MethodKey$sub_refs	_jc_java_lang_Class__24MethodKey$sub_refs;
typedef struct _jc_java_lang_Class__24MethodKey$sub_nonrefs	_jc_java_lang_Class__24MethodKey$sub_nonrefs;
typedef struct _jc_java_lang_Class__24MethodKey$refs	_jc_java_lang_Class__24MethodKey$refs;
typedef struct _jc_java_lang_Class__24MethodKey$nonrefs	_jc_java_lang_Class__24MethodKey$nonrefs;
typedef struct _jc_java_lang_Class__24MethodKey$object	_jc_java_lang_Class__24MethodKey$object;

typedef const struct _jc_java_lang_Class__24MethodKey$vmethods	_jc_java_lang_Class__24MethodKey$vmethods;
typedef const struct _jc_java_lang_Class__24MethodKey$vtable	_jc_java_lang_Class__24MethodKey$vtable;
typedef const struct _jc_java_lang_Class__24MethodKey$vtype	_jc_java_lang_Class__24MethodKey$vtype;

// Constructors
extern void _jc_java_lang_Class__24MethodKey$method$_init$29c13095b73e79e4(_jc_env *, struct _jc_java_lang_Class__24MethodKey$object *, struct _jc_java_lang_reflect_Method$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_lang_Class__24MethodKey$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_lang_Class__24MethodKey$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_java_lang_Class__24MethodKey$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_lang_Class__24MethodKey$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_lang_Class__24MethodKey$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_lang_Class__24MethodKey$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_java_lang_Class__24MethodKey$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_lang_Class__24MethodKey$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_lang_Class__24MethodKey$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_lang_Class__24MethodKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Class__24MethodKey$vmethods	java_lang_Class__24MethodKey;
};

// Vtype
struct _jc_java_lang_Class__24MethodKey$vtype {
	_jc_type			type;
	_jc_java_lang_Class__24MethodKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_Class__24MethodKey$sub_refs {
	struct _jc_java_lang_String$object	*name;
	_jc_object_array	*params;
	struct _jc_java_lang_Class$object	*returnType;
};

// Reference instance fields (object)
struct _jc_java_lang_Class__24MethodKey$refs {
    _jc_java_lang_Class__24MethodKey$sub_refs	java_lang_Class__24MethodKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_Class__24MethodKey$sub_nonrefs {
	jint	hash;
};

// Non-reference instance fields (object)
struct _jc_java_lang_Class__24MethodKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Class__24MethodKey$sub_nonrefs	java_lang_Class__24MethodKey;
};

// Object instance structure
struct _jc_java_lang_Class__24MethodKey$object {
	_jc_java_lang_Class__24MethodKey$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_Class__24MethodKey$vtype	*vtype;
	_jc_java_lang_Class__24MethodKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_Class__24MethodKey$vtype _jc_java_lang_Class__24MethodKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_Class__24MethodKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_Class__24MethodKey$class_object;

#endif	/* _JC_java_lang_Class__24MethodKey_H_ */
